==> sql-streams-0.1.1-sources.jar: be/bendem/sqlstreams/util/DummyDataSource.java <==
package be.bendem.sqlstreams.util;

import javax.sql.DataSource;
import java.io.PrintWriter;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.SQLFeatureNotSupportedException;
import java.util.logging.Logger;

/**
 * A stupid {@link DataSource} implementation that throws {@link UnsupportedOperationException} for every method except
 * {@link #getConnection()} and {@link #getConnection(String, String)}.
 *
 * This {@code DataSource} is used by {@link be.bendem.sqlstreams.Sql#connect(Connection)}.
 */
abstract class DummyDataSource implements DataSource {

    /**
     * Parameters passed to this method are ignored, this is equivalent to calling {@link #getConnection()} directly.
     */
    @Override
    public Connection getConnection(String username, String password) throws SQLException {
        return getConnection();
    }

    @Override
    public <T> T unwrap(Class<T> iface) throws SQLException {
        throw new UnsupportedOperationException();
    }

    @Override
    public boolean isWrapperFor(Class<?> iface) throws SQLException {
        throw new UnsupportedOperationException();
    }

    @Override
    public PrintWriter getLogWriter() throws SQLException {
        throw new UnsupportedOperationException();
    }

    @Override
    public void setLogWriter(PrintWriter out) throws SQLException {
        throw new UnsupportedOperationException();
    }

    @Override
    public void setLoginTimeout(int seconds) throws SQLException {
        throw new UnsupportedOperationException();
    }

    @Override
    public int getLoginTimeout() throws SQLException {
        throw new UnsupportedOperationException();
    }

    @Override
    public Logger getParentLogger() throws SQLFeatureNotSupportedException {
        throw new UnsupportedOperationException();
    }
}

==> sql-streams-1.0.0-sources.jar: be/bendem/sqlstreams/util/DummyDataSource.java <==
package be.bendem.sqlstreams.util;

import be.bendem.sqlstreams.SqlStream;

import javax.sql.DataSource;
import java.io.PrintWriter;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.SQLFeatureNotSupportedException;
import java.util.logging.Logger;

/**
 * A stupid {@link DataSource} implementation that throws {@link UnsupportedOperationException} for every method except
 * {@link #getConnection()} and {@link #getConnection(String, String)}.
 *
 * This {@code DataSource} is used by {@link SqlStream#connect(Connection)}.
 */
abstract class DummyDataSource implements DataSource {

    /**
     * Parameters passed to this method are ignored, this is equivalent to calling {@link #getConnection()} directly.
     */
    @Override
    public Connection getConnection(String username, String password) throws SQLException {
        return getConnection();
    }

    @Override
    public <T> T unwrap(Class<T> iface) throws SQLException {
        throw new UnsupportedOperationException();
    }

    @Override
    public boolean isWrapperFor(Class<?> iface) throws SQLException {
        throw new UnsupportedOperationException();
    }

    @Override
    public PrintWriter getLogWriter() throws SQLException {
        throw new UnsupportedOperationException();
    }

    @Override
    public void setLogWriter(PrintWriter out) throws SQLException {
        throw new UnsupportedOperationException();
    }

    @Override
    public void setLoginTimeout(int seconds) throws SQLException {
        throw new UnsupportedOperationException();
    }

    @Override
    public int getLoginTimeout() throws SQLException {
        throw new UnsupportedOperationException();
    }

    @Override
    public Logger getParentLogger() throws SQLFeatureNotSupportedException {
        throw new UnsupportedOperationException();
    }
}
